==> europepmc_0.1.2.tar.gz: europepmc/R/defunct.r <==

search_publications <- function(...)
{
  .Defunct("epmc_search", "europepmc", "Function removed,
           you can get this info using epmc_search")
}

get_MESH <- function(...)
{
  .Defunct("epmc_details", "europepmc", "Function removed,
           you can get this info using epmc_details")
}


get_grants <- function(...)
{
  .Defunct("epmc_details", "europepmc", "Function removed,
           you can get this info using epmc_details")
}


get_chemicals <- function(...)
{
  .Defunct("epmc_details", "europepmc", "Function removed,
           you can get this info using epmc_details")
}


get_author <- function(...)
{
  .Defunct("epmc_details", "europepmc", "Function removed,
           you can get this info using epmc_details")
}


get_comments <- function(...)
{
  .Defunct("epmc_details", "europepmc", "Function removed,
           you can get this info using epmc_details")
}


get_journal_info <- function(...)
{
  .Defunct("epmc_details", "europepmc", "Function removed,
           you can get this info using epmc_details")
}


get_fulltext <- function(...)
{
  .Defunct("epmc_details", "europepmc", "Function removed,
           you can get this info using epmc_details")
}


get_citations <- function(...)
{
  .Defunct("epmc_citations", "europepmc", "Function removed,
           you can get this info using epmc_citations")
}


get_references <- function(...)
{
  .Defunct("epmc_refs", "europepmc", "Function removed,
           you can get this info using epmc_refs")
}


lablinkxml <-function(...)
{
  .Defunct("lablinkxml", "europepmc", "Function removed.")
}


parse_ftxt <-function(...)
{
  .Defunct("parse_ftxt", "europepmc", "Function removed, use epmc_ftxt instead")
}


dblinkcount <-function(...)
{
  .Defunct("dblinkcount", "europepmc", "Function removed, use epmc_db_count instead")
}


dblinkdata <-function(...)
{
  .Defunct("dblinkdata", "europepmc", "Function removed, use epmc_db instead")
}

==> europepmc_0.3.tar.gz: europepmc/R/defunct.r <==

search_publications <- function(...)
{
  .Defunct("epmc_search", "europepmc", "Function removed,
           you can get this info using epmc_search")
}

get_MESH <- function(...)
{
  .Defunct("epmc_details", "europepmc", "Function removed,
           you can get this info using epmc_details")
}


get_grants <- function(...)
{
  .Defunct("epmc_details", "europepmc", "Function removed,
           you can get this info using epmc_details")
}


get_chemicals <- function(...)
{
  .Defunct("epmc_details", "europepmc", "Function removed,
           you can get this info using epmc_details")
}


get_author <- function(...)
{
  .Defunct("epmc_details", "europepmc", "Function removed,
           you can get this info using epmc_details")
}


get_comments <- function(...)
{
  .Defunct("epmc_details", "europepmc", "Function removed,
           you can get this info using epmc_details")
}


get_journal_info <- function(...)
{
  .Defunct("epmc_details", "europepmc", "Function removed,
           you can get this info using epmc_details")
}


get_fulltext <- function(...)
{
  .Defunct("epmc_details", "europepmc", "Function removed,
           you can get this info using epmc_details")
}


get_citations <- function(...)
{
  .Defunct("epmc_citations", "europepmc", "Function removed,
           you can get this info using epmc_citations")
}


get_references <- function(...)
{
  .Defunct("epmc_refs", "europepmc", "Function removed,
           you can get this info using epmc_refs")
}


lablinkxml <-function(...)
{
  .Defunct("lablinkxml", "europepmc", "Function removed.")
}


parse_ftxt <-function(...)
{
  .Defunct("parse_ftxt", "europepmc", "Function removed, use epmc_ftxt instead")
}


dblinkcount <-function(...)
{
  .Defunct("dblinkcount", "europepmc", "Function removed,
           use epmc_db_count instead")
}


dblinkdata <-function(...)
{
  .Defunct("dblinkdata", "europepmc", "Function removed, use epmc_db instead")
}
